"use client";

import { updateAlbumSortOrder } from "@/actions/albums/updateAlbumSortOrder";
import { SortableCardItem } from "@/components/sort/SortableItem";
import { SortableList } from "@/components/sort/SortableList";
import { Album, Gallery, Image } from "@/generated/prisma";
import { SortableItem } from "@/types/SortableItem";
import { useEffect, useState } from "react";

type AlbumWithGallery = Album & {
  gallery: Gallery | null;
  images: { id: string }[];
  coverImage?: (Image) | null
};

export default function ListAlbums({ albums }: { albums: AlbumWithGallery[] }) {
  const [isMounted, setIsMounted] = useState(false);

  useEffect(() => {
    setIsMounted(true);
  }, []);

  const sortableItems: SortableItem[] = albums.map(album => ({
    id: album.id,
    sortIndex: album.sortIndex,
    label: album.name,
  }));

  const handleSortDefault = async () => {
    const sorted = [...sortableItems]
      .sort((a, b) => a.label.localeCompare(b.label))
      .map((item, index) => ({ ...item, sortIndex: index * 10 }));
    await updateAlbumSortOrder(sorted);
  };

  const handleReorder = async (items: SortableItem[]) => {
    await updateAlbumSortOrder(items);
  };

  if (!isMounted) return null;

  return (
    <SortableList
      items={sortableItems}
      onReorder={handleReorder}
      onSortDefault={handleSortDefault}
      defaultSortLabel="Sort by name"
      renderItem={(item) => {
        const album = albums.find(g => g.id === item.id)!;
        return (
          <SortableCardItem
            id={album.id}
            item={{
              id: album.id,
              name: album.name,
              type: "album",
              coverImage: album.coverImage,
              count: album.images.length,
              textLabel: "Gallery: " + album.gallery?.name
            }}
          />
        );
      }}
    />
  );
}