"use client";

import { updateArtistSortOrder } from "@/actions/artists/updateArtistSortOrder";
import { SortableCardItem } from "@/components/sort/SortableItem";
import { SortableList } from "@/components/sort/SortableList";
import { Artist } from "@/generated/prisma";
import { SortableItem } from "@/types/SortableItem";
import { useEffect, useState } from "react";

type ArtistsWithItems = Artist & {
  images: { id: string }[]
}

export default function ListArtists({ artists }: { artists: ArtistsWithItems[] }) {
  const [isMounted, setIsMounted] = useState(false);

  useEffect(() => {
    setIsMounted(true);
  }, []);

  const sortableItems: SortableItem[] = artists.map(artist => ({
    id: artist.id,
    sortIndex: artist.sortIndex,
    label: artist.displayName,
  }));

  const handleSortDefault = async () => {
    const sorted = [...sortableItems]
      .sort((a, b) => a.label.localeCompare(b.label))
      .map((item, index) => ({ ...item, sortIndex: index * 10 }));
    await updateArtistSortOrder(sorted);
  };

  const handleReorder = async (items: SortableItem[]) => {
    await updateArtistSortOrder(items);
  };

  if (!isMounted) return null;

  return (
    <SortableList
      items={sortableItems}
      onReorder={handleReorder}
      onSortDefault={handleSortDefault}
      defaultSortLabel="Sort by displayName"
      renderItem={(item) => {
        const artist = artists.find(g => g.id === item.id)!;
        return (
          <SortableCardItem
            id={artist.id}
            item={{
              id: artist.id,
              name: artist.displayName,
              type: "artist",
              count: artist.images.length
            }}
          />
        );
      }}
    />
  );
}