"use client";

import { updateCategorySortOrder } from "@/actions/categories/updateCategorySortOrder";
import { SortableCardItem } from "@/components/sort/SortableItem";
import { SortableList } from "@/components/sort/SortableList";
import { Category } from "@/generated/prisma";
import { SortableItem } from "@/types/SortableItem";
import { useEffect, useState } from "react";

type CategoriesWithItems = Category & {
  images: { id: string }[]
}

export default function ListCategories({ categories }: { categories: CategoriesWithItems[] }) {
  const [isMounted, setIsMounted] = useState(false);

  useEffect(() => {
    setIsMounted(true);
  }, []);

  const sortableItems: SortableItem[] = categories.map(cat => ({
    id: cat.id,
    sortIndex: cat.sortIndex,
    label: cat.name,
  }));

  const handleSortDefault = async () => {
    const sorted = [...sortableItems]
      .sort((a, b) => a.label.localeCompare(b.label))
      .map((item, index) => ({ ...item, sortIndex: index * 10 }));
    await updateCategorySortOrder(sorted);
  };

  const handleReorder = async (items: SortableItem[]) => {
    await updateCategorySortOrder(items);
  };

  if (!isMounted) return null;

  return (
    <SortableList
      items={sortableItems}
      onReorder={handleReorder}
      onSortDefault={handleSortDefault}
      defaultSortLabel="Sort by name"
      renderItem={(item) => {
        const cat = categories.find(g => g.id === item.id)!;
        return (
          <SortableCardItem
            id={cat.id}
            item={{
              id: cat.id,
              name: cat.name,
              type: "category",
              count: cat.images.length
            }}
          />
        );
      }}
    />
  );
}