"use client";

import { updateGallerySortOrder } from "@/actions/galleries/updateGallerySortOrder";
import { SortableCardItem } from "@/components/sort/SortableItem";
import { SortableList } from "@/components/sort/SortableList";
import { Gallery, Image } from "@/generated/prisma";
import { SortableItem } from "@/types/SortableItem";
import { useEffect, useState } from "react";

type GalleriesWithItems = Gallery & {
  albums: { id: string }[],
  coverImage?: (Image) | null
};

export default function ListGalleries({ galleries }: { galleries: GalleriesWithItems[] }) {
  const [isMounted, setIsMounted] = useState(false);

  useEffect(() => {
    setIsMounted(true);
  }, []);

  const sortableItems: SortableItem[] = galleries.map(gallery => ({
    id: gallery.id,
    sortIndex: gallery.sortIndex,
    label: gallery.name,
  }));

  const handleSortDefault = async () => {
    const sorted = [...sortableItems]
      .sort((a, b) => a.label.localeCompare(b.label))
      .map((item, index) => ({ ...item, sortIndex: index * 10 }));
    await updateGallerySortOrder(sorted);
  };

  const handleReorder = async (items: SortableItem[]) => {
    await updateGallerySortOrder(items);
  };

  if (!isMounted) return null;

  return (
    <SortableList
      items={sortableItems}
      onReorder={handleReorder}
      onSortDefault={handleSortDefault}
      defaultSortLabel="Sort by name"
      renderItem={(item) => {
        const gallery = galleries.find(g => g.id === item.id)!;
        return (
          <SortableCardItem
            id={gallery.id}
            item={{
              id: gallery.id,
              name: gallery.name,
              type: "gallery",
              coverImage: gallery.coverImage,
              count: gallery.albums.length,
            }}
          />
        );
      }}
    />
  );
}
