"use client";

import { updateTagSortOrder } from "@/actions/tags/updateTagSortOrder";
import { SortableCardItem } from "@/components/sort/SortableItem";
import { SortableList } from "@/components/sort/SortableList";
import { Tag } from "@/generated/prisma";
import { SortableItem } from "@/types/SortableItem";
import { useEffect, useState } from "react";

type TagsWithItems = Tag & {
  images: { id: string }[]
}
export default function ListTags({ tags }: { tags: TagsWithItems[] }) {
  const [isMounted, setIsMounted] = useState(false);

  useEffect(() => {
    setIsMounted(true);
  }, []);

  const sortableItems: SortableItem[] = tags.map(tag => ({
    id: tag.id,
    sortIndex: tag.sortIndex,
    label: tag.name,
  }));

  const handleSortDefault = async () => {
    const sorted = [...sortableItems]
      .sort((a, b) => a.label.localeCompare(b.label))
      .map((item, index) => ({ ...item, sortIndex: index * 10 }));
    await updateTagSortOrder(sorted);
  };

  const handleReorder = async (items: SortableItem[]) => {
    await updateTagSortOrder(items);
  };

  if (!isMounted) return null;

  return (
    <SortableList
      items={sortableItems}
      onReorder={handleReorder}
      onSortDefault={handleSortDefault}
      defaultSortLabel="Sort by name"
      renderItem={(item) => {
        const tag = tags.find(g => g.id === item.id)!;
        return (
          <SortableCardItem
            id={tag.id}
            item={{
              id: tag.id,
              name: tag.name,
              type: "tag",
              count: tag.images.length
            }}
          />
        );
      }}
    />
  );
}